@@ -6,8 +6,8 @@ from datetime import date, time
 from enum import Enum
 from typing import List, Optional
 
-from pydantic import BaseModel, Field
-from .base import AindSchema
+from pydantic import Field
+from .base import AindCoreModel, AindModel
 
 
 class ProtectiveMaterial(Enum):
@@ -19,7 +19,17 @@ class ProtectiveMaterial(Enum):
     OTHER = "Other - see notes"
 
 
-class Procedure(BaseModel):
+class Anaesthetic(AindModel):
+    """Description of an anaestheic"""
+
+    type: str = Field(..., title="Type")
+    duration: float = Field(..., title="Duration (hours)", units="hours")
+    level: float = Field(
+        ..., title="Level (percent)", units="percent", ge=1, le=5
+    )
+
+
+class Procedure(AindModel):
     """Description of surgical or other procedure performed on a subject"""
 
     type: Optional[str] = Field(
@@ -42,6 +52,7 @@ class Procedure(BaseModel):
         description="Animal weight before procedure",
         units="g",
     )
+    anaesthesia: Optional[Anaesthetic] = Field(None, title="Anaesthesia")
     notes: Optional[str] = Field(None, title="Notes")
 
 
@@ -98,7 +109,7 @@ class VirusPrepType(Enum):
     PURIFIED = "Purified"
 
 
-class InjectionMaterial(BaseModel):
+class InjectionMaterial(AindModel):
     """Description of injection material"""
 
     name: str = Field(..., title="Name")
@@ -133,6 +144,9 @@ class Injection(Procedure):
         None, title="Injection material", unique_items=True
     )
     injection_duration: time = Field(..., title="Injection duration")
+    recovery_time: float = Field(..., title="Recovery time (min)", units="min")
+    workstation_id: Optional[str] = Field(None, title="Workstation ID")
+    instrument_id: Optional[str] = Field(None, title="Instrument ID")
 
 
 class RetroOrbitalInjection(Injection):
@@ -258,7 +272,7 @@ class TissuePrep(Procedure):
     specimen_id: List[str] = Field(..., title="Specimen ID")
 
 
-class TrainingProtocol(BaseModel):
+class TrainingProtocol(AindModel):
     """Description of an animal training protocol"""
 
     protocol_id: str = Field(..., title="Training protocol ID")
@@ -286,7 +300,7 @@ class FerruleMaterial(Enum):
     STAINLESS_STEEL = "Stainless steel"
 
 
-class OphysProbe(BaseModel):
+class OphysProbe(AindModel):
     """Description of an ophys probe"""
 
     name: ProbeName = Field(..., title="Name")
@@ -319,7 +333,7 @@ class FiberImplant(Procedure):
     )
 
 
-class WaterRestriction(BaseModel):
+class WaterRestriction(AindModel):
     """Description of a water restriction procedure"""
 
     protocol_id: Optional[str] = Field(
@@ -334,11 +348,11 @@ class WaterRestriction(BaseModel):
     end_date: date = Field(..., title="Water restriction end date")
 
 
-class Procedures(AindSchema):
+class Procedures(AindCoreModel):
     """Description of all procedures performed on a subject"""
 
     schema_version: str = Field(
-        "0.4.2", description="schema version", title="Version", const=True
+        "0.4.3", description="schema version", title="Version", const=True
     )
     subject_id: str = Field(
         ...,
